@@ -2683,7 +2683,7 @@ static int trigger_failover_command(int node, const char *command_line,
 							string_append_char(exec_cmd, newmaster->backend_hostname);
 						else
 							/* no vaid new master */
-							string_append_char(exec_cmd, "");
+							string_append_char(exec_cmd, "\"\"");
 						break;
 
 					case 'm': /* new master node id */
@@ -2700,7 +2700,7 @@ static int trigger_failover_command(int node, const char *command_line,
 						}
 						else
 							/* no vaid new master */
-							string_append_char(exec_cmd, "");
+							string_append_char(exec_cmd, "\"\"");
 						break;
 
 					case 'R': /* new master database directory */
@@ -2709,7 +2709,7 @@ static int trigger_failover_command(int node, const char *command_line,
 							string_append_char(exec_cmd, newmaster->backend_data_directory);
 						else
 							/* no vaid new master */
-							string_append_char(exec_cmd, "");
+							string_append_char(exec_cmd, "\"\"");
 						break;
 
 					case 'M': /* old master node id */
